@@ -1,7 +1,9 @@
 package App::LocaleCodesUtils;
 
-our $DATE = '2018-03-07'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-02'; # DATE
+our $DIST = 'App-LocaleCodesUtils'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -47,17 +49,19 @@ $res = gen_read_table_func(
     summary => 'List countries',
     table_data => sub {
         require Locale::Country;
-        my @codes = Locale::Country::all_country_codes();
+        my @alpha2s = Locale::Country::all_country_codes('alpha-2');
         my @data;
-        for (@codes) {
-            push @data, [$_, Locale::Country::code2country($_)];
+        for my $alpha2 (@alpha2s) {
+            my $country = Locale::Country::code2country($alpha2, 'alpha-2');
+            my $alpha3  = Locale::Country::country2code($country, 'alpha-3');
+            push @data, [$alpha2, $country, $alpha3];
         }
         return { data=>\@data };
     },
     table_spec => {
         summary => 'List of countries',
         fields => {
-            code => {
+            alpha2 => {
                 schema => 'str*',
                 pos => 0,
                 sortable => 1,
@@ -67,8 +71,13 @@ $res = gen_read_table_func(
                 pos => 1,
                 sortable => 1,
             },
+            alpha3 => {
+                schema => 'str*',
+                pos => 2,
+                sortable => 1,
+            },
         },
-        pk => 'code',
+        pk => 'alpha2',
     },
 );
 die "Can't generate list_countries(): $res->[0] - $res->[1]" unless $res->[0] == 200;
@@ -78,17 +87,19 @@ $res = gen_read_table_func(
     summary => 'List languages',
     table_data => sub {
         require Locale::Language;
-        my @codes = Locale::Language::all_language_codes();
+        my @alpha2s = Locale::Language::all_language_codes('alpha-2');
         my @data;
-        for (@codes) {
-            push @data, [$_, Locale::Language::code2language($_)];
+        for my $alpha2 (@alpha2s) {
+            my $lang   = Locale::Language::code2language($alpha2, 'alpha-2');
+            my $alpha3 = Locale::Language::language2code($lang, 'alpha-3');
+            push @data, [$alpha2, $lang, $alpha3];
         }
         return { data=>\@data };
     },
     table_spec => {
         summary => 'List of languages',
         fields => {
-            code => {
+            alpha2 => {
                 schema => 'str*',
                 pos => 0,
                 sortable => 1,
@@ -98,8 +109,13 @@ $res = gen_read_table_func(
                 pos => 1,
                 sortable => 1,
             },
+            alpha3 => {
+                schema => 'str*',
+                pos => 2,
+                sortable => 1,
+            },
         },
-        pk => 'code',
+        pk => 'alpha2',
     },
 );
 die "Can't generate list_languages(): $res->[0] - $res->[1]" unless $res->[0] == 200;
@@ -150,7 +166,7 @@ App::LocaleCodesUtils - Utilities related to locale codes
 
 =head1 VERSION
 
-This document describes version 0.002 of App::LocaleCodesUtils (from Perl distribution App-LocaleCodesUtils), released on 2018-03-07.
+This document describes version 0.003 of App::LocaleCodesUtils (from Perl distribution App-LocaleCodesUtils), released on 2020-03-02.
 
 =head1 DESCRIPTION
 
@@ -175,7 +191,7 @@ This distributions provides the following command-line utilities:
 
 Usage:
 
- list_countries(%args) -> [status, msg, result, meta]
+ list_countries(%args) -> [status, msg, payload, meta]
 
 List countries.
 
@@ -187,49 +203,93 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<code> => I<str>
+=item * B<alpha2> => I<str>
 
-Only return records where the 'code' field equals specified value.
+Only return records where the 'alpha2' field equals specified value.
 
-=item * B<code.contains> => I<str>
+=item * B<alpha2.contains> => I<str>
 
-Only return records where the 'code' field contains specified text.
+Only return records where the 'alpha2' field contains specified text.
 
-=item * B<code.in> => I<array[str]>
+=item * B<alpha2.in> => I<array[str]>
 
-Only return records where the 'code' field is in the specified values.
+Only return records where the 'alpha2' field is in the specified values.
 
-=item * B<code.is> => I<str>
+=item * B<alpha2.is> => I<str>
 
-Only return records where the 'code' field equals specified value.
+Only return records where the 'alpha2' field equals specified value.
 
-=item * B<code.isnt> => I<str>
+=item * B<alpha2.isnt> => I<str>
 
-Only return records where the 'code' field does not equal specified value.
+Only return records where the 'alpha2' field does not equal specified value.
 
-=item * B<code.max> => I<str>
+=item * B<alpha2.max> => I<str>
 
-Only return records where the 'code' field is less than or equal to specified value.
+Only return records where the 'alpha2' field is less than or equal to specified value.
 
-=item * B<code.min> => I<str>
+=item * B<alpha2.min> => I<str>
 
-Only return records where the 'code' field is greater than or equal to specified value.
+Only return records where the 'alpha2' field is greater than or equal to specified value.
 
-=item * B<code.not_contains> => I<str>
+=item * B<alpha2.not_contains> => I<str>
 
-Only return records where the 'code' field does not contain specified text.
+Only return records where the 'alpha2' field does not contain specified text.
 
-=item * B<code.not_in> => I<array[str]>
+=item * B<alpha2.not_in> => I<array[str]>
 
-Only return records where the 'code' field is not in the specified values.
+Only return records where the 'alpha2' field is not in the specified values.
 
-=item * B<code.xmax> => I<str>
+=item * B<alpha2.xmax> => I<str>
 
-Only return records where the 'code' field is less than specified value.
+Only return records where the 'alpha2' field is less than specified value.
 
-=item * B<code.xmin> => I<str>
+=item * B<alpha2.xmin> => I<str>
 
-Only return records where the 'code' field is greater than specified value.
+Only return records where the 'alpha2' field is greater than specified value.
+
+=item * B<alpha3> => I<str>
+
+Only return records where the 'alpha3' field equals specified value.
+
+=item * B<alpha3.contains> => I<str>
+
+Only return records where the 'alpha3' field contains specified text.
+
+=item * B<alpha3.in> => I<array[str]>
+
+Only return records where the 'alpha3' field is in the specified values.
+
+=item * B<alpha3.is> => I<str>
+
+Only return records where the 'alpha3' field equals specified value.
+
+=item * B<alpha3.isnt> => I<str>
+
+Only return records where the 'alpha3' field does not equal specified value.
+
+=item * B<alpha3.max> => I<str>
+
+Only return records where the 'alpha3' field is less than or equal to specified value.
+
+=item * B<alpha3.min> => I<str>
+
+Only return records where the 'alpha3' field is greater than or equal to specified value.
+
+=item * B<alpha3.not_contains> => I<str>
+
+Only return records where the 'alpha3' field does not contain specified text.
+
+=item * B<alpha3.not_in> => I<array[str]>
+
+Only return records where the 'alpha3' field is not in the specified values.
+
+=item * B<alpha3.xmax> => I<str>
+
+Only return records where the 'alpha3' field is less than specified value.
+
+=item * B<alpha3.xmin> => I<str>
+
+Only return records where the 'alpha3' field is greater than specified value.
 
 =item * B<detail> => I<bool> (default: 0)
 
@@ -237,6 +297,10 @@ Return array of full records instead of just ID fields.
 
 By default, only the key (ID) field is returned per result entry.
 
+=item * B<exclude_fields> => I<array[str]>
+
+Select fields to return.
+
 =item * B<fields> => I<array[str]>
 
 Select fields to return.
@@ -310,12 +374,13 @@ specify descending order instead of the default ascending.
 
 =item * B<with_field_names> => I<bool>
 
-Return field names in each record (as hash/associative array).
+Return field names in each record (as hashE<sol>associative array).
 
 When enabled, function will return each record as hash/associative array
 (field name => value pairs). Otherwise, function will return each record
 as list/array (field value, field value, ...).
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -323,18 +388,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 list_currencies
 
 Usage:
 
- list_currencies(%args) -> [status, msg, result, meta]
+ list_currencies(%args) -> [status, msg, payload, meta]
 
 List currencies.
 
@@ -396,6 +462,10 @@ Return array of full records instead of just ID fields.
 
 By default, only the key (ID) field is returned per result entry.
 
+=item * B<exclude_fields> => I<array[str]>
+
+Select fields to return.
+
 =item * B<fields> => I<array[str]>
 
 Select fields to return.
@@ -469,12 +539,13 @@ specify descending order instead of the default ascending.
 
 =item * B<with_field_names> => I<bool>
 
-Return field names in each record (as hash/associative array).
+Return field names in each record (as hashE<sol>associative array).
 
 When enabled, function will return each record as hash/associative array
 (field name => value pairs). Otherwise, function will return each record
 as list/array (field value, field value, ...).
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -482,18 +553,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 list_languages
 
 Usage:
 
- list_languages(%args) -> [status, msg, result, meta]
+ list_languages(%args) -> [status, msg, payload, meta]
 
 List languages.
 
@@ -505,49 +577,93 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<code> => I<str>
+=item * B<alpha2> => I<str>
 
-Only return records where the 'code' field equals specified value.
+Only return records where the 'alpha2' field equals specified value.
 
-=item * B<code.contains> => I<str>
+=item * B<alpha2.contains> => I<str>
 
-Only return records where the 'code' field contains specified text.
+Only return records where the 'alpha2' field contains specified text.
 
-=item * B<code.in> => I<array[str]>
+=item * B<alpha2.in> => I<array[str]>
 
-Only return records where the 'code' field is in the specified values.
+Only return records where the 'alpha2' field is in the specified values.
 
-=item * B<code.is> => I<str>
+=item * B<alpha2.is> => I<str>
 
-Only return records where the 'code' field equals specified value.
+Only return records where the 'alpha2' field equals specified value.
 
-=item * B<code.isnt> => I<str>
+=item * B<alpha2.isnt> => I<str>
 
-Only return records where the 'code' field does not equal specified value.
+Only return records where the 'alpha2' field does not equal specified value.
 
-=item * B<code.max> => I<str>
+=item * B<alpha2.max> => I<str>
 
-Only return records where the 'code' field is less than or equal to specified value.
+Only return records where the 'alpha2' field is less than or equal to specified value.
 
-=item * B<code.min> => I<str>
+=item * B<alpha2.min> => I<str>
 
-Only return records where the 'code' field is greater than or equal to specified value.
+Only return records where the 'alpha2' field is greater than or equal to specified value.
 
-=item * B<code.not_contains> => I<str>
+=item * B<alpha2.not_contains> => I<str>
 
-Only return records where the 'code' field does not contain specified text.
+Only return records where the 'alpha2' field does not contain specified text.
 
-=item * B<code.not_in> => I<array[str]>
+=item * B<alpha2.not_in> => I<array[str]>
 
-Only return records where the 'code' field is not in the specified values.
+Only return records where the 'alpha2' field is not in the specified values.
 
-=item * B<code.xmax> => I<str>
+=item * B<alpha2.xmax> => I<str>
 
-Only return records where the 'code' field is less than specified value.
+Only return records where the 'alpha2' field is less than specified value.
 
-=item * B<code.xmin> => I<str>
+=item * B<alpha2.xmin> => I<str>
 
-Only return records where the 'code' field is greater than specified value.
+Only return records where the 'alpha2' field is greater than specified value.
+
+=item * B<alpha3> => I<str>
+
+Only return records where the 'alpha3' field equals specified value.
+
+=item * B<alpha3.contains> => I<str>
+
+Only return records where the 'alpha3' field contains specified text.
+
+=item * B<alpha3.in> => I<array[str]>
+
+Only return records where the 'alpha3' field is in the specified values.
+
+=item * B<alpha3.is> => I<str>
+
+Only return records where the 'alpha3' field equals specified value.
+
+=item * B<alpha3.isnt> => I<str>
+
+Only return records where the 'alpha3' field does not equal specified value.
+
+=item * B<alpha3.max> => I<str>
+
+Only return records where the 'alpha3' field is less than or equal to specified value.
+
+=item * B<alpha3.min> => I<str>
+
+Only return records where the 'alpha3' field is greater than or equal to specified value.
+
+=item * B<alpha3.not_contains> => I<str>
+
+Only return records where the 'alpha3' field does not contain specified text.
+
+=item * B<alpha3.not_in> => I<array[str]>
+
+Only return records where the 'alpha3' field is not in the specified values.
+
+=item * B<alpha3.xmax> => I<str>
+
+Only return records where the 'alpha3' field is less than specified value.
+
+=item * B<alpha3.xmin> => I<str>
+
+Only return records where the 'alpha3' field is greater than specified value.
 
 =item * B<detail> => I<bool> (default: 0)
 
@@ -555,6 +671,10 @@ Return array of full records instead of just ID fields.
 
 By default, only the key (ID) field is returned per result entry.
 
+=item * B<exclude_fields> => I<array[str]>
+
+Select fields to return.
+
 =item * B<fields> => I<array[str]>
 
 Select fields to return.
@@ -628,12 +748,13 @@ specify descending order instead of the default ascending.
 
 =item * B<with_field_names> => I<bool>
 
-Return field names in each record (as hash/associative array).
+Return field names in each record (as hashE<sol>associative array).
 
 When enabled, function will return each record as hash/associative array
 (field name => value pairs). Otherwise, function will return each record
 as list/array (field value, field value, ...).
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -641,18 +762,19 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
 
 
+
 =head2 list_scripts
 
 Usage:
 
- list_scripts(%args) -> [status, msg, result, meta]
+ list_scripts(%args) -> [status, msg, payload, meta]
 
 List scripts.
 
@@ -714,6 +836,10 @@ Return array of full records instead of just ID fields.
 
 By default, only the key (ID) field is returned per result entry.
 
+=item * B<exclude_fields> => I<array[str]>
+
+Select fields to return.
+
 =item * B<fields> => I<array[str]>
 
 Select fields to return.
@@ -787,12 +913,13 @@ specify descending order instead of the default ascending.
 
 =item * B<with_field_names> => I<bool>
 
-Return field names in each record (as hash/associative array).
+Return field names in each record (as hashE<sol>associative array).
 
 When enabled, function will return each record as hash/associative array
 (field name => value pairs). Otherwise, function will return each record
 as list/array (field value, field value, ...).
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -800,7 +927,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -834,7 +961,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
